package cn.iocoder.yudao.module.system.controller.admin.houselane;

import cn.iocoder.yudao.module.system.controller.admin.houselane.vo.WareHouseLanePageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.houselane.vo.WareHouseLaneRespVO;
import cn.iocoder.yudao.module.system.controller.admin.houselane.vo.WareHouseLaneSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.houselane.WareHouseLaneDO;
import cn.iocoder.yudao.module.system.service.houselane.WareHouseLaneService;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.*;


@Tag(name = "管理后台 - 线库/巷道")
@RestController
@RequestMapping("/system/ware/house-lane")
@Validated
public class WareHouseLaneController {

    @Resource
    private WareHouseLaneService houseLaneService;

    @PostMapping("/create")
    @Operation(summary = "创建线库/巷道")
    @PreAuthorize("@ss.hasPermission('ware:house-lane:create')")
    public CommonResult<Long> createHouseLane(@Valid @RequestBody WareHouseLaneSaveReqVO createReqVO) {
        return success(houseLaneService.createHouseLane(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新线库/巷道")
    @PreAuthorize("@ss.hasPermission('ware:house-lane:update')")
    public CommonResult<Boolean> updateHouseLane(@Valid @RequestBody WareHouseLaneSaveReqVO updateReqVO) {
        houseLaneService.updateHouseLane(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除线库/巷道")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('ware:house-lane:delete')")
    public CommonResult<Boolean> deleteHouseLane(@RequestParam("id") Long id) {
        houseLaneService.deleteHouseLane(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得线库/巷道")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('ware:house-lane:query')")
    public CommonResult<WareHouseLaneRespVO> getHouseLane(@RequestParam("id") Long id) {
        WareHouseLaneDO houseLane = houseLaneService.getHouseLane(id);
        return success(BeanUtils.toBean(houseLane, WareHouseLaneRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得线库/巷道分页")
    @PreAuthorize("@ss.hasPermission('ware:house-lane:query')")
    public CommonResult<PageResult<WareHouseLaneRespVO>> getHouseLanePage(@Valid WareHouseLanePageReqVO pageReqVO) {
        PageResult<WareHouseLaneDO> pageResult = houseLaneService.getHouseLanePage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, WareHouseLaneRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出线库/巷道 Excel")
    @PreAuthorize("@ss.hasPermission('ware:house-lane:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportHouseLaneExcel(@Valid WareHouseLanePageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<WareHouseLaneDO> list = houseLaneService.getHouseLanePage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "线库/巷道.xls", "数据", WareHouseLaneRespVO.class,
                        BeanUtils.toBean(list, WareHouseLaneRespVO.class));
    }

}