package cn.iocoder.yudao.module.system.controller.admin.positionmap;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionMapItemPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionMapItemRespVO;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionMapItemSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.positionmap.PositionMapItemDO;
import cn.iocoder.yudao.module.system.service.positionmap.PositionMapItemService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 仓库点位地图子表")
@RestController
@RequestMapping("/system/position-map-item")
@Validated
public class PositionMapItemController {

    @Resource
    private PositionMapItemService positionMapItemService;

    @PostMapping("/create")
    @Operation(summary = "创建仓库点位地图子表")
    @PreAuthorize("@ss.hasPermission('system:position-map-item:create')")
    public CommonResult<Long> createPositionMapItem(@Valid @RequestBody PositionMapItemSaveReqVO createReqVO) {
        return success(positionMapItemService.createPositionMapItem(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新仓库点位地图子表")
    @PreAuthorize("@ss.hasPermission('system:position-map-item:update')")
    public CommonResult<Boolean> updatePositionMapItem(@Valid @RequestBody PositionMapItemSaveReqVO updateReqVO) {
        positionMapItemService.updatePositionMapItem(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除仓库点位地图子表")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('system:position-map-item:delete')")
    public CommonResult<Boolean> deletePositionMapItem(@RequestParam("id") Long id) {
        positionMapItemService.deletePositionMapItem(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得仓库点位地图子表")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('system:position-map-item:query')")
    public CommonResult<PositionMapItemRespVO> getPositionMapItem(@RequestParam("id") Long id) {
        PositionMapItemDO positionMapItem = positionMapItemService.getPositionMapItem(id);
        return success(BeanUtils.toBean(positionMapItem, PositionMapItemRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得仓库点位地图子表分页")
    @PreAuthorize("@ss.hasPermission('system:position-map-item:query')")
    public CommonResult<PageResult<PositionMapItemRespVO>> getPositionMapItemPage(@Valid PositionMapItemPageReqVO pageReqVO) {
        PageResult<PositionMapItemDO> pageResult = positionMapItemService.getPositionMapItemPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, PositionMapItemRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出仓库点位地图子表 Excel")
    @PreAuthorize("@ss.hasPermission('system:position-map-item:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportPositionMapItemExcel(@Valid PositionMapItemPageReqVO pageReqVO,
                                           HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<PositionMapItemDO> list = positionMapItemService.getPositionMapItemPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "仓库点位地图子表.xls", "数据", PositionMapItemRespVO.class,
                BeanUtils.toBean(list, PositionMapItemRespVO.class));
    }

}
