package cn.iocoder.yudao.module.system.controller.admin.positionmap;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionMapLinePageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionMapLineRespVO;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionMapLineSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.positionmap.PositionMapLineDO;
import cn.iocoder.yudao.module.system.service.positionmap.PositionMapLineService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Tag(name = "管理后台 - 仓库点位地图连线")
@RestController
@RequestMapping("/system/position-map-line")
@Validated
public class PositionMapLineController {

    @Resource
    private PositionMapLineService positionMapLineService;

    @PostMapping("/create")
    @Operation(summary = "创建仓库点位地图连线")
    @PreAuthorize("@ss.hasPermission('system:position-map-line:create')")
    public CommonResult<Long> createPositionMapLine(@Valid @RequestBody PositionMapLineSaveReqVO createReqVO) {
        return success(positionMapLineService.createPositionMapLine(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新仓库点位地图连线")
    @PreAuthorize("@ss.hasPermission('system:position-map-line:update')")
    public CommonResult<Boolean> updatePositionMapLine(@Valid @RequestBody PositionMapLineSaveReqVO updateReqVO) {
        positionMapLineService.updatePositionMapLine(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除仓库点位地图连线")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('system:position-map-line:delete')")
    public CommonResult<Boolean> deletePositionMapLine(@RequestParam("id") Long id) {
        positionMapLineService.deletePositionMapLine(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得仓库点位地图连线")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('system:position-map-line:query')")
    public CommonResult<PositionMapLineRespVO> getPositionMapLine(@RequestParam("id") Long id) {
        PositionMapLineDO positionMapLine = positionMapLineService.getPositionMapLine(id);
        return success(BeanUtils.toBean(positionMapLine, PositionMapLineRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得仓库点位地图连线分页")
    @PreAuthorize("@ss.hasPermission('system:position-map-line:query')")
    public CommonResult<PageResult<PositionMapLineRespVO>> getPositionMapLinePage(@Valid PositionMapLinePageReqVO pageReqVO) {
        PageResult<PositionMapLineDO> pageResult = positionMapLineService.getPositionMapLinePage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, PositionMapLineRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出仓库点位地图连线 Excel")
    @PreAuthorize("@ss.hasPermission('system:position-map-line:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportPositionMapLineExcel(@Valid PositionMapLinePageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<PositionMapLineDO> list = positionMapLineService.getPositionMapLinePage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "仓库点位地图连线.xls", "数据", PositionMapLineRespVO.class,
                        BeanUtils.toBean(list, PositionMapLineRespVO.class));
    }

}
