package cn.iocoder.yudao.module.system.service.housearea;

import cn.iocoder.yudao.module.system.controller.admin.housearea.vo.HouseAreaPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.housearea.vo.HouseAreaSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.housearea.HouseAreaDO;
import cn.iocoder.yudao.module.system.dal.mysql.housearea.HouseAreaMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;


import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.HOUSE_AREA_NOT_EXISTS;

/**
 * 库区 Service 实现类
 *
 * @author 陈宾顺
 */
@Service
@Validated
public class HouseAreaServiceImpl implements HouseAreaService {

    @Resource
    private HouseAreaMapper houseAreaMapper;

    @Override
    public Long createHouseArea(HouseAreaSaveReqVO createReqVO) {
        // 插入
        HouseAreaDO houseArea = BeanUtils.toBean(createReqVO, HouseAreaDO.class);
        houseAreaMapper.insert(houseArea);
        // 返回
        return houseArea.getId();
    }

    @Override
    public void updateHouseArea(HouseAreaSaveReqVO updateReqVO) {
        // 校验存在
        validateHouseAreaExists(updateReqVO.getId());
        // 更新
        HouseAreaDO updateObj = BeanUtils.toBean(updateReqVO, HouseAreaDO.class);
        houseAreaMapper.updateById(updateObj);
    }

    @Override
    public void deleteHouseArea(Long id) {
        // 校验存在
        validateHouseAreaExists(id);
        // 删除
        houseAreaMapper.deleteById(id);
    }

    private void validateHouseAreaExists(Long id) {
        if (houseAreaMapper.selectById(id) == null) {
            throw exception(HOUSE_AREA_NOT_EXISTS);
        }
    }

    @Override
    public HouseAreaDO getHouseArea(Long id) {
        return houseAreaMapper.selectById(id);
    }

    @Override
    public PageResult<HouseAreaDO> getHouseAreaPage(HouseAreaPageReqVO pageReqVO) {
        return houseAreaMapper.selectPage(pageReqVO);
    }

}