package cn.iocoder.yudao.module.system.service.houselane;

import cn.iocoder.yudao.module.system.controller.admin.houselane.vo.WareHouseLanePageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.houselane.vo.WareHouseLaneSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.houselane.WareHouseLaneDO;
import cn.iocoder.yudao.module.system.dal.mysql.houselane.WareHouseLaneMapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;


import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.HOUSE_LANE_NOT_EXISTS;


/**
 * 线库/巷道 Service 实现类
 *
 * @author 陈宾顺
 */
@Service
@Validated
public class WareHouseLaneServiceImpl implements WareHouseLaneService {

    @Resource
    private WareHouseLaneMapper houseLaneMapper;

    @Override
    public Long createHouseLane(WareHouseLaneSaveReqVO createReqVO) {
        // 插入
        WareHouseLaneDO houseLane = BeanUtils.toBean(createReqVO, WareHouseLaneDO.class);
        houseLaneMapper.insert(houseLane);
        // 返回
        return houseLane.getId();
    }

    @Override
    public void updateHouseLane(WareHouseLaneSaveReqVO updateReqVO) {
        // 校验存在
        validateHouseLaneExists(updateReqVO.getId());
        // 更新
        WareHouseLaneDO updateObj = BeanUtils.toBean(updateReqVO, WareHouseLaneDO.class);
        houseLaneMapper.updateById(updateObj);
    }

    @Override
    public void deleteHouseLane(Long id) {
        // 校验存在
        validateHouseLaneExists(id);
        // 删除
        houseLaneMapper.deleteById(id);
    }

    private void validateHouseLaneExists(Long id) {
        if (houseLaneMapper.selectById(id) == null) {
            throw exception(HOUSE_LANE_NOT_EXISTS);
        }
    }

    @Override
    public WareHouseLaneDO getHouseLane(Long id) {
        return houseLaneMapper.selectById(id);
    }

    @Override
    public PageResult<WareHouseLaneDO> getHouseLanePage(WareHouseLanePageReqVO pageReqVO) {
        return houseLaneMapper.selectPage(pageReqVO);
    }

}